@@ -24,9 +24,6 @@ use BeamerReveal::FrameConverter;
 
 sub dieExit;
 
-my $version = 0.95;
-my $author  = 'Walter Daems <walter.daems@uantwerpen.be>';
-
 ######################################
 # Read command-line options/arguments
 ####################################
@@ -57,9 +54,17 @@ pod2usage( -message => "Incorrect number of arguments",
 ########################
 # generate opening line
 ######################
-my $openingline = "beamer-reveal.pl - v$version - $author";
-say STDERR $openingline . "\n" .
-  ("=" x length( $openingline ) );
+my $openinglines =
+  [
+   '**************************************************************************',
+   "* beamer-reveal.pl                                        v${BeamerReveal::VERSION} *",
+   '* (C) 2026 by Walter Daems <walter.daems@uantwerpen.be>            GPLv3 *',
+   '**************************************************************************',
+  ];
+
+foreach my $line ( @$openinglines ) {
+  say STDERR $line;
+}
 
 ###################
 # do the hard work
@@ -194,7 +199,7 @@ beamer-reveal.pl - converts the .rvl file and the corresponding pdf file to a fu
 
 =head1 VERSION
 
-version 20251226.2020
+version 20251226.2107
 
 =head1 SYNOPSIS
 
